@@ -83,18 +83,18 @@ def CreateHeader():
             h=h+"\n"+"No alarm set"
         h=h+"\n"+"Alarm Time Window Start: "+strftime(data.dateformat,records.AlarmTimeWindowStart_tuple)
         h=h+"\n"+"Alarm Time Window End: "+strftime(data.dateformat,records.AlarmTimeWindowEnd_tuple)
-        h=h+"\n"+"Alarm Use external: "+str(data.UseAlternativeAlarm)
+        h=h+"\n"+"Use alternative Alarm: "+str(data.UseAlternativeAlarm)
         if(data.UseAlternativeAlarm==True):
-            h=h+"\n"+"Alarm External: "+str(data.AlternativeAlarm)
+            h=h+"\n"+"Alternative Alarm: "+str(data.AlternativeAlarm)
         else:
-            h=h+"\n"+"Alarm External: "
+            h=h+"\n"+"Alternative Alarm: "
 
     else:
         h=h+"\n"+"No alarm set"
         h=h+"\n"+"Alarm Time Window Start: Not set"
         h=h+"\n"+"Alarm Time Window End: Not set"
-        h=h+"\n"+"Alarm Use external: False"
-        h=h+"\n"+"Alarm External: "
+        h=h+"\n"+"Use alternative Alarm: False"
+        h=h+"\n"+"Alternative Alarm: "
 
     h=h+"\n"+"Note: "+str(records.Note.encode( "utf-8" ))
 
@@ -284,13 +284,13 @@ def LoadRecord():
             if(records.SWversion>=2.1):
                 #process header line 6
                 tmp=file.readline()
-                tmp=string.replace(tmp[:-1], "Alarm Use external: ",  "")
+                tmp=string.replace(tmp[:-1], "Use alternative Alarm: ",  "")
                 if(tmp=="False"): records.UseAlternativeAlarm=False
                 else: records.UseAlternativeAlarm=True
 
                 #process header line 7
                 tmp=file.readline()
-                records.AlternativeAlarm=string.replace(tmp[:-1], "Alarm External: ",  "")
+                records.AlternativeAlarm=string.replace(tmp[:-1], "Alternative Alarm: ",  "")
 
            #process header line 8
             tmp=file.readline()
