@@ -86,7 +86,8 @@ def LoadConfig():
     try:
         data.Yscale_Movement = config.getint('main', 'Yscale_Movement')
     except:
-        config.set('main', 'Yscale_Movement', str(data.Yscale_Movement_default))
+        data.Yscale_Movement=data.Yscale_Movement_default
+        config.set('main', 'Yscale_Movement', str(data.Yscale_Movement))
 
     try:
         data.derivation_offset = config.getint('main', 'derivation_offset')
@@ -96,12 +97,14 @@ def LoadConfig():
     try:
         data.Yscale_Sleep_Pattern = config.getint('main', 'Yscale_Sleep_Pattern')
     except:
-        config.set('main', 'Yscale_Sleep_Pattern', str(data.Yscale_Sleep_Pattern_default))
+        data.Yscale_Sleep_Pattern=data.Yscale_Sleep_Pattern_default
+        config.set('main', 'Yscale_Sleep_Pattern', str(data.Yscale_Sleep_Pattern))
 
     try:
         data.Yoffset_Sleep_Pattern = config.getint('main', 'Yoffset_Sleep_Pattern')
     except:
-        config.set('main', 'Yoffset_Sleep_Pattern', str(data.Yoffset_Sleep_Pattern_default))
+        data.Yoffset_Sleep_Pattern=data.Yoffset_Sleep_Pattern_default
+        config.set('main', 'Yoffset_Sleep_Pattern', str(data.Yoffset_Sleep_Pattern))
 
     try:
         data.limitMovement = config.getint('main', 'limitMovement')
@@ -248,7 +251,8 @@ def LoadConfig():
         config.set('main', 'Deep_Sleep_Level', str(data.Deep_Sleep_Level))
 
 
-
+    print "data.Light_Sleep_Level:", data.Light_Sleep_Level
+    print "data.Deep_Sleep_Level:", data.Deep_Sleep_Level
 
 
 
@@ -272,6 +276,7 @@ def LoadConfig():
         pass
 
     print "Configuration successful loaded from "+data.ConfigFile
+    PrintConfig()
     return config
 
 
